@@ -28,7 +28,7 @@ Usage::
     describe_load_balancers_paginator: DescribeLoadBalancersPaginator = client.get_paginator("describe_load_balancers")
     ```
 """
-from mypy_boto3_elb.client import ElasticLoadBalancingClient, ElasticLoadBalancingClient as Client
+from mypy_boto3_elb.client import ElasticLoadBalancingClient
 from mypy_boto3_elb.paginator import DescribeAccountLimitsPaginator, DescribeLoadBalancersPaginator
 from mypy_boto3_elb.waiter import (
     AnyInstanceInServiceWaiter,
@@ -36,6 +36,8 @@ from mypy_boto3_elb.waiter import (
     InstanceInServiceWaiter,
 )
 
+Client = ElasticLoadBalancingClient
+
 
 __all__ = (
     "AnyInstanceInServiceWaiter",
